### **How to Set Up GrowwMCP with Claude Desktop**

This guide will help you connect your GrowwMCP to Claude Desktop, allowing you to analyse your portfolio, placing orders, analyse market and lot more using simple chat commands.

---

#### **Step 1: Install Prerequisite Software**

To get started, please install the following applications on your computer.

1.  **Python 3.10:** [! Required, it is mandatory to use python 3.10, the package isn't supported by python version <= 3.9]
    *   Install Python by following the official guide at this URL:
    *   [https://www.python.org/downloads/release/python-31018/](https://www.python.org/downloads/release/python-31018/)

2.  **uv (A Python Package Installer):**
    *   Use the official documentation at the following link to install `uv`:
    *   [https://docs.astral.sh/uv/getting-started/installation/](https://docs.astral.sh/uv/getting-started/installation/)

> **Important:** Mac users should install Python and uv using the command below. (If you do not have administrative privileges, please contact your IT Administrator). Do not try `pip install uv` to avoid unexpected behavior


```zsh
brew install uv
brew install python@3.10
```

3. **Install the Claude Desktop Application**
    *   Obtain the installer for your specific operating system from https://claude.ai/download and execute it. (Administrator permissions are necessary).
    [On macOS, this will download as a .dmg file. Double-click it to launch the installer.]

> **Important:** It is recommended to use administrator/root privileges when installing the above tools. This will help ensure that Claude can locate and utilize them correctly.

---


#### **Step 2: Get Your Groww API Credentials**

To connect Claude to your Groww account, you need special keys. You must first have access to the Groww API.

1.  Visit the Groww API documentation to get your **API Key**, **API Secret**, and set up your **TOTP secret**.
    *   [https://groww.in/trade-api/docs/python-sdk#2nd-approach-totp-flow](https://groww.in/trade-api/docs/python-sdk#2nd-approach-totp-flow)
2.  Keep these keys safe and ready for the next step.

---

#### **Step 3: Configure Claude Desktop**

Now, you will tell Claude Desktop how to run the Groww tool.

1.  Open your Claude Desktop configuration file.
    *   For help finding this file, see the official guide here (you do not need to install Node.js): [https://modelcontextprotocol.io/quickstart/user](https://modelcontextprotocol.io/quickstart/user)

2.  In the configuration file, find the `mcpServers` section and add the following code inside it:

    ```json
    {
        "mcpServers": {
            "growwmcp": {
                "command": "uv",
                "args": [
                    "run",
                    "--python",
                    "3.10",
                    "--with",
                    "growwmcp",
                    "python",
                    "-m",
                    "growwmcp",
                    "--stdio"
                ],
                "env": {
                    "GROWW_API_KEY": "<your api key here>",
                    "GROWW_API_SECRET": "<your api secret here>"
                }
            }
        }
    }
    ```

3.  Replace `<your api key here>` and `<your api secret here>` with the actual keys you got from Groww in Step 2.

4.  Save and close the configuration file.

---

#### **Step 4: Verify the Setup**

1.  Restart your Claude Desktop application.
2.  Check the "Search & Tools" section in Claude. You should see **growwmcp** listed as an available tool.
    *   *Note: It may take 10-15 seconds for the tool to appear the first time while it sets up.*

    ![Image showing 'growwmcp' in the Claude Desktop tool list](assets/claude_groww_mcp.png)

---

#### **Step 5: Start Using the Groww Tool**

Once confirmed, you can start chatting with Claude to manage your portfolio. Try commands like but not limited to:

*   `Place an order for 5 units of Reliance stock`
*   `Find next Thursday's NIFTY 25000 PE contract`
*   `What is my current portfolio value?`

#### **(Optional) For Better Responses**

You can help Claude understand how to use the Groww tool more effectively by adding a system prompt.

1.  In the Claude Desktop chat interface, click the **`+`** button.
2.  Find the `growwmcp` section and click **"Add"** next to `prompt_template_prompt`.

![Image showing how to add the system prompt in Claude Desktop](assets/claude_sys_prompt.png)

This will give Claude better instructions, leading to more accurate results. You are all set


### **Security/Vulnerability**

> This package is supposed be run by a mcp supported tool (i.e. claude desktop) so ensure you trust claude desktop with your data, and keep your `<your api key here>` and `<your api secret here>` safe.